Random Generators
=================

.. toctree::

   reference_generator_example
   reference_generator_profile_ordinal_uniform
   reference_generator_profile_ordinal_grid_uniform
   reference_generator_profile_ordinal_variations
   reference_generator_profile_histogram_uniform
   reference_generator_strategy_ordinal_uniform
   reference_generator_strategy_threshold_uniform
   reference_generator_tau_vector_uniform
   reference_generator_tau_vector_grid_uniform
